@@ -18,16 +18,16 @@ class VideoPlaybackSettings():
     """
     Provides the video playback settings.
     """
-    playbackFormat = "18"
-    formatList = ["17", "18"]
+    playbackFormat = 18
+    formatList = [17, 18]
     
 class VideoDownloadSettings():
     """
     Provides the video download settings.
     """
     downloadFolder = "/home/user/MyDocs/.videos"
-    downloadFormat = "18"
-    formatList = ["17", "18", "34", "35", "22"]
+    downloadFormat = 18
+    formatList = [17, 18, 34, 35, 22]
     defaultTaskStatus = "queued"
     
 class SearchSettings():
