@@ -3,9 +3,10 @@
 """
 Module implementing the dialogs for cuteTube.
 """
-
+import os
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
+from PyQt4.QtWebKit import QWebView
 try:
     from PyQt4.QtMaemo5 import QMaemo5ListPickSelector, QMaemo5AbstractPickSelector, QMaemo5InformationBox, QMaemo5ValueButton
 except:
@@ -13,7 +14,7 @@ except:
 import youtubeservice
 import cutetubewindows
 from cutetubeconfig import *
-import os
+from videosharing import Twitter
 from Ui_addtoplaylistdialog import Ui_AddToPlaylistDialog
 from Ui_newplaylistdialog import Ui_NewPlaylistDialog
 from Ui_confirmdeletedialog import Ui_ConfirmDeleteDialog
@@ -1056,4 +1057,229 @@ class NoAccountFoundDialog(QDialog,  Ui_NoAccountFoundDialog):
         in YouTubeDataService to False.
         """
         YouTubeAPISettings.raiseNoAccountFoundDialog = False
+        
+class ShareVideoDialog(QDialog):
+    """
+    Dialog presenting the user with the available video sharing options.
+    """
+    def __init__(self, parent, videoUrl):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+        self.setWindowTitle("Share This Video")
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+        self.videoUrl = videoUrl
+        self.clipboardButton = QPushButton(QIcon(":/images/ui-images/clipboardicon.png"), "Copy to clipboard", self)
+        self.twitterButton = QPushButton(QIcon(":/images/ui-images/twittericon.png"), "Share via twitter", self)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.orientationChanged()
+        self.connect(self.clipboardButton, SIGNAL("clicked()"), self.copyToClipboard)
+        self.connect(self.twitterButton, SIGNAL("clicked()"), self.shareViaTwitter)
+        self.show()
+        
+    def orientationChanged(self):
+        """
+        Re-orders the widgets when the application 
+        is in portrait mode.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.resize(480, 170)
+            self.clipboardButton.setGeometry(QRect(10, 10, 460, 70))
+            self.twitterButton.setGeometry(QRect(10, 90, 460, 70))
+        else:
+            self.resize(800, 90)
+            self.clipboardButton.setGeometry(QRect(10, 10, 300, 70))
+            self.twitterButton.setGeometry(QRect(490, 10, 300, 70))
+            
+    def toggleBusy(self, isBusy = False):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
+            
+    def copyToClipboard(self):
+        """
+        Copies the video URL to the clipboard.
+        """
+        clipboard = QApplication.clipboard()
+        clipboard.setText(self.videoUrl)
+        QMaemo5InformationBox.information(self, "Video URL copied")
+        self.accept()
+        
+    def shareViaTwitter(self):
+        """
+        Raises a ShareViaTwitterDialog.
+        """
+        self.toggleBusy(True)
+        if not VideoSharingSettings.raiseTwitterAuthorisationDialog:
+            shareViaTwitterDialog = ShareViaTwitterDialog(self, self.videoUrl)
+            self.connect(shareViaTwitterDialog, SIGNAL("accepted()"), self.accept)
+        else:
+            twitterAuthorisationDialog = TwitterAuthorisationDialog(self)
+            self.connect(twitterAuthorisationDialog, SIGNAL("accepted()"), self.shareViaTwitter)
+        self.toggleBusy(False)
+
+class TwitterAuthorisationDialog(QDialog):
+    """
+    Displays the Twitter web page and a line edit enabling the 
+    user to provide Twitter authorisation.
+    """
+    def __init__(self, parent):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+        self.setWindowTitle("Twitter Authorisation")
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+        self.webView = QWebView(self)
+        self.webView.setZoomFactor(0.6)
+        self.pinLabel = QLabel("Enter pin code", self)
+        self.pinLabel.setStyleSheet("color: rgb(120, 120, 120)")
+        self.pinEdit = QLineEdit(self)
+        self.submitButton = QPushButton("Submit", self)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.orientationChanged()
+        self.connect(self.submitButton, SIGNAL("clicked()"), self.getTwitterAccess)
+        self.connect(self.webView, SIGNAL("loadFinished(bool)"), self.loadFinished)
+        self.show()
+        self.loadTwitterPage()
+        
+    def orientationChanged(self):
+        """
+        Re-orders the widgets when the application 
+        is in portrait mode.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.resize(480, 510)
+            self.webView.setGeometry(QRect(10, 10, 460, 300))
+            self.pinLabel.setGeometry(QRect(10, 320, 400, 30))
+            self.pinEdit.setGeometry(QRect(10, 350, 460, 70))
+            self.submitButton.setGeometry(QRect(10, 430, 460, 70))
+        else:
+            self.resize(800, 370)
+            self.webView.setGeometry(QRect(10, 10, 590, 250))
+            self.pinLabel.setGeometry(QRect(10, 260, 400, 30))
+            self.pinEdit.setGeometry(QRect(10, 290, 590, 70))
+            self.submitButton.setGeometry(QRect(640, 290, 150, 70))
+            
+    def toggleBusy(self, isBusy = False):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
+        
+    def loadFinished(self):
+        """
+        Removes the progress indicator.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+        
+    def loadTwitterPage(self):
+        """
+        Loads the Twitter authorisation page into the QWebView.
+        """
+        self.toggleBusy(True)
+        try:
+            url = Twitter.getAuthorisationUrl()
+            self.webView.load(QUrl(url))
+        except:
+            QMaemo5InformationBox.information(self, "Unable to connect to Twitter")
+            self.toggleBusy()
+            
+    def getTwitterAccess(self):
+        """
+        Retrieves the access token key and access token secret.
+        """
+        if self.pinEdit.text() != "":
+            pincode = unicode(self.pinEdit.text(), "utf-8")
+            self.toggleBusy(True)
+            try:
+                accessTokenKey, accessTokenSecret = Twitter.getAccessToken(pincode)
+                VideoSharingSettings.twitterAccessTokenKey = accessTokenKey
+                VideoSharingSettings.twitterAccessTokenSecret = accessTokenSecret
+                QMaemo5InformationBox.information(self, "cuteTube is now authorised to access your Twitter account")
+                VideoSharingSettings.raiseTwitterAuthorisationDialog = False
+                self.accept()
+            except:
+                QMaemo5InformationBox.information(self, "Unable to complete authorisation. Please check the pin code and try again")
+            self.toggleBusy()
+                
+class ShareViaTwitterDialog(QDialog):
+    """
+    Dialog enabling the user to share the video via Twitter.
+    """
+    def __init__(self, parent, videoUrl):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+        self.setWindowTitle("Share Via Twitter")
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+        self.messageEdit = QTextEdit(videoUrl, self)
+        self.charLabel = QLabel(self)
+        self.charLabel.setStyleSheet("color: rgb(120, 120, 120)")
+        self.setCharCount()
+        self.submitButton = QPushButton("Submit", self)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        self.orientationChanged()
+        self.connect(self.messageEdit, SIGNAL("textChanged()"), self.setCharCount)
+        self.connect(self.submitButton, SIGNAL("clicked()"), self.shareViaTwitter)
+        self.show()
+        
+    def orientationChanged(self):
+        """
+        Re-orders the widgets when the application 
+        is in portrait mode.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.resize(480, 270)
+            self.charLabel.setGeometry(QRect(10, 10, 200, 30))
+            self.messageEdit.setGeometry(QRect(10, 40, 460, 140))
+            self.submitButton.setGeometry(QRect(10, 190, 460, 70))
+        else:
+            self.resize(800, 190)
+            self.charLabel.setGeometry(QRect(10, 10, 200, 30))
+            self.messageEdit.setGeometry(QRect(10, 40, 590, 140))
+            self.submitButton.setGeometry(QRect(640, 110, 150, 70))
+            
+    def toggleBusy(self, isBusy = False):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
+            
+    def setCharCount(self):
+        """
+        Sets the text of the charLabel to inform the user how many 
+        additional characters are allowed.
+        """
+        messageLength = self.messageEdit.toPlainText().length()
+        count = unicode(140 - messageLength)
+        self.charLabel.setText(count)
+        
+    def shareViaTwitter(self):
+        """
+        Shares the video and accompanying message via Twitter.
+        """
+        message = unicode(self.messageEdit.toPlainText(), "utf-8")
+        if message != "":
+            self.toggleBusy(True)
+            try:
+                Twitter.postMessage(message)
+                QMaemo5InformationBox.information(self, "Your message has been posted to Twitter")
+                self.accept()
+            except:
+                QMaemo5InformationBox.information(self, "Unable to post message to Twitter")
+            self.toggleBusy()
+            
+        
+        
+
             
