@@ -1288,7 +1288,7 @@ class DownloadsWindow(CutetubeWindows):
         is enabled, otherwise a VideoInfoWindow is created.
         """
         row = self.listWidget.row(item)
-        video = youtubeservice.YouTubeVideoDownloader.downloadQueue[row]
+        video = youtubeservice.YouTubeVideoDownloader.taskQueue[row].video
         videoInfoWindow = videoinfowindow.VideoInfoWindow(self, video)
         self.connect(videoInfoWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
         self.listWidget.setCurrentRow(-1)
