@@ -111,10 +111,12 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         YouTubeAPISettings.userDict = settings.value("userDict",  {}).toPyObject()
         YouTubeAPISettings.defaultUser = settings.value("defaultUser",  "").toString()
         YouTubeAPISettings.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
-        VideoPlaybackSettings.playbackFormat = settings.value("playbackFormat",  "18").toPyObject()
+        if VideoPlaybackSettings.playbackFormat in (17, 18):
+            VideoPlaybackSettings.playbackFormat = settings.value("playbackFormat",  18).toInt()[0]
         VideoDownloadSettings.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
         VideoDownloadSettings.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
-        VideoDownloadSettings.downloadFormat = settings.value("downloadFormat",  "18").toPyObject()
+        if VideoDownloadSettings.downloadFormat in (17, 18, 34, 35, 22):
+            VideoDownloadSettings.downloadFormat = settings.value("downloadFormat",  18).toInt()[0]
         VideoSharingSettings.raiseTwitterAuthorisationDialog = settings.value("twitterAuthDialog", True).toBool()
         VideoSharingSettings.twitterAccessTokenKey = settings.value("twitterKey", "").toString()
         VideoSharingSettings.twitterAccessTokenSecret = settings.value("twitterSecret", "").toString()
