@@ -49,6 +49,9 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.actionRateVideo.setVisible(False)
             self.actionUserVideos.setVisible(False)
             self.actionEditVideo.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser == "":
+            self.actionAddToFavourites.setVisible(False)
+            self.actionAddToPlaylist.setVisible(False)
         self.show()
         self.loadData()
 
@@ -143,9 +146,11 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         videoTitle = self.video.title.text
         try:
+            self.toggleBusy(True)
             videoPlaybackWindow = VideoPlaybackWindow(self, video = self.video)
         except:
             QMaemo5InformationBox.information(self, "Unable to play video")
+        self.toggleBusy(False)
 
     def downloadVideo(self):
         videoTitle = self.video.media.title.text
@@ -267,6 +272,14 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         playlist to which to add the current video.
         """
         playlistDialog = cutetubedialogs.AddToPlaylistDialog(self, [self.video])
+        
+    @pyqtSignature("")
+    def on_actionShareVideo_triggered(self):
+        """
+        Raises a ShareVideoDialog.
+        """
+        videoUrl = self.video.media.player.url.split("&")[0]
+        shareVideoDialog = cutetubedialogs.ShareVideoDialog(self, videoUrl)
 
     @pyqtSignature("")
     def on_actionEditVideo_triggered(self):
