@@ -175,31 +175,37 @@ class YouTubeDataService(object):
         YouTubeDataService.ytService.DeleteVideoEntry(videoEntry)
 
     @staticmethod
-    def getVideoUrl(video,  videoFormat = "18"):
+    def getVideoUrl(video,  videoFormat = 18):
         """
         Returns the YouTube video url for download or playback.
         In the case of a download, if the user-chosen format is not 
         available, the next available format will be used.
+        Much of the code for this method is borrowed from youtube.py 
+        of MediaBox.
         """
-        videoUrl = ""        
-        if "playlists" in video.id.text:
-            videoId = video.comments.feed_link[0].href.split("/")[-2]
-        else:
-            videoId = video.id.text.split("/")[-1]
-        for elType in ['&el=embedded', '&el=detailpage', '&el=vevo', '']:
-            videoInfoUrl = ('http://www.youtube.com/get_video_info?&video_id=%s%s&ps=default&eurl=&gl=US&hl=en' % (videoId, elType))
-            request = urllib2.Request(videoInfoUrl, None, YouTubeDataService.stdHeaders)
-            videoInfoWebpage = urllib2.urlopen(request).read()
-            videoInfo = parse_qs(videoInfoWebpage)
-            if 'token' in videoInfo:
-                videoToken = urllib.unquote_plus(videoInfo['token'][0])
-                formatList = ['22', '35', '34', '18', '17']
-                for format in formatList[formatList.index(videoFormat):]:
-                    videoUrl = 'http://www.youtube.com/get_video?video_id=%s&t=%s&eurl=&el=&ps=&asv=&fmt=%s' % (videoId, videoToken,  format)
-                    videoLength = urllib.urlopen(videoUrl).info()["Content-Length"]
-                    if videoLength !="0":
-                        break
+        videoUrl = ""       
+        playerUrl = video.media.player.url.split("&")[0]
+        html = urllib.urlopen(playerUrl).read()
+        html = "".join(html.split())
+        formats = {}
+        pos = html.find("\",\"fmt_url_map\":\"")
+        if (pos != -1):
+            pos2 = html.find("\"", pos + 17)
+            fmt_map = urllib.unquote(html[pos + 17:pos2]) + ","
+            parts = fmt_map.split("|")
+            key = parts[0]
+            for p in parts[1:]:
+                idx = p.rfind(",")
+                value = p[:idx].replace("\\/", "/")
+                formats[int(key)] = value
+                key = p[idx + 1:]
+            
+        formatList = [22, 35, 34, 18, 17]
+        for format in formatList[formatList.index(videoFormat):]:
+            if videoFormat in formats:
+                videoUrl = formats.get(videoFormat)
                 break
+            break
         return videoUrl
 
 class YouTubeVideoFeed(QThread):
